==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/CASEMANAGEMENTRELATEDCASEID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CASEMANAGEMENTRELATEDCASEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CASEMANAGEMENTRELATEDCASEID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HEADERCASE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RELATEDCASEID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CASEMANAGEMENTRELATEDCASEID_Type", propOrder = {
    "headercase",
    "relatedcaseid"
})
public class CASEMANAGEMENTRELATEDCASEID_Type {

    @XmlElement(name = "HEADERCASE", required = true)
    protected CASEID_Type headercase;
    @XmlElement(name = "RELATEDCASEID", required = true)
    protected CASEID_Type relatedcaseid;

    /**
     * Gets the value of the headercase property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getHEADERCASE() {
        return headercase;
    }

    /**
     * Sets the value of the headercase property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setHEADERCASE(CASEID_Type value) {
        this.headercase = value;
    }

    /**
     * Gets the value of the relatedcaseid property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getRELATEDCASEID() {
        return relatedcaseid;
    }

    /**
     * Sets the value of the relatedcaseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setRELATEDCASEID(CASEID_Type value) {
        this.relatedcaseid = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/CASEMANAGEMENTRELATEDCASEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CASEMANAGEMENTRELATEDCASEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CASEMANAGEMENTRELATEDCASEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HEADERCASE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDCASEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CASEMANAGEMENTRELATEDCASEID_Type", propOrder = {
    "headercase",
    "relatedcaseid"
})
public class CASEMANAGEMENTRELATEDCASEID_Type {

    @XmlElement(name = "HEADERCASE", required = true)
    protected CASEID_Type headercase;
    @XmlElement(name = "RELATEDCASEID", required = true)
    protected CASEID_Type relatedcaseid;

    /**
     * Gets the value of the headercase property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getHEADERCASE() {
        return headercase;
    }

    /**
     * Sets the value of the headercase property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setHEADERCASE(CASEID_Type value) {
        this.headercase = value;
    }

    /**
     * Gets the value of the relatedcaseid property.
     * 
     * @return
     *     possible object is
     *     {@link CASEID_Type }
     *     
     */
    public CASEID_Type getRELATEDCASEID() {
        return relatedcaseid;
    }

    /**
     * Sets the value of the relatedcaseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CASEID_Type }
     *     
     */
    public void setRELATEDCASEID(CASEID_Type value) {
        this.relatedcaseid = value;
    }

}
